package org.openoffice.test.jarindex;

import java.util.logging.Level;
import java.util.logging.Logger;

import com.sun.star.awt.*;
import com.sun.star.beans.PropertyValue;
import com.sun.star.frame.XDispatch;
import com.sun.star.frame.XFrame;
import com.sun.star.frame.XStatusListener;
import com.sun.star.lib.uno.helper.WeakBase;
import com.sun.star.uno.Exception;
import com.sun.star.uno.UnoRuntime;
import com.sun.star.uno.XComponentContext;
import com.sun.star.util.URL;

/**
 * @author d.de.wit
 * 
 */
public class TestAction extends WeakBase implements XDispatch {
	private static final Logger logger = Logger.getLogger(TestAction.class.getName());
	
	private final XFrame frame;
	private final XComponentContext context;

	/**
	 * 
	 */
	public TestAction(XComponentContext context, XFrame frame) {
		this.context = context;
		this.frame = frame;
	}

	public void dispatch(URL arg0, PropertyValue[] arg1) {
		logger.info("dispatch TestAction");
		try {
			new DialogHelper(context).showMessageBox(frame, "TEST", "Jar index test succeeded");
		} catch (Throwable e) {
			logger.log(Level.SEVERE, "failed to show dialog via utils jar", e);
			showMessageBox(frame, "TEST", "Jar index test FAILED!");
		}
	}

	public void addStatusListener(XStatusListener arg0, URL arg1) {}

	public void removeStatusListener(XStatusListener arg0, URL arg1) {}
	
	public void showMessageBox(XFrame frame, String sTitle, String sMessage) {
		if (frame == null) {
			return;
		}
		try {
			XToolkit toolkit = (XToolkit) UnoRuntime.queryInterface(XToolkit.class, context.getServiceManager()
					.createInstanceWithContext("com.sun.star.awt.Toolkit", context));
			
			// describe window properties.
			WindowDescriptor aDescriptor = new WindowDescriptor();
			aDescriptor.Type = WindowClass.MODALTOP;
			aDescriptor.WindowServiceName = new String("infobox");
			aDescriptor.ParentIndex = -1;
			aDescriptor.Parent = (XWindowPeer) UnoRuntime.queryInterface(XWindowPeer.class, frame.getContainerWindow());
			aDescriptor.Bounds = new Rectangle(0, 0, 300, 200);
			aDescriptor.WindowAttributes = WindowAttribute.BORDER | WindowAttribute.MOVEABLE
			| WindowAttribute.CLOSEABLE;
			
			XWindowPeer xPeer = toolkit.createWindow(aDescriptor);
			if (null != xPeer) {
				XMessageBox xMsgBox = (XMessageBox) UnoRuntime.queryInterface(XMessageBox.class, xPeer);
				if (null != xMsgBox) {
					xMsgBox.setCaptionText(sTitle);
					xMsgBox.setMessageText(sMessage);
					xMsgBox.execute();
				}
			} 
		} catch (Exception e) {
			logger.log(Level.SEVERE, "failed to show dialog", e);
		}
	}

}
